@@ -9,6 +9,7 @@ import os
 import stat
 import errno
 import json
+import sys
 #internal imports
 import subuserlib.permissions
 from subuserlib.classes.userOwnedObject import UserOwnedObject
@@ -111,6 +112,10 @@ Please run:
 $ subuser repair
 
 To repair your subuser installation.\n""")
+    except SyntaxError as e:
+      sys.exit("The subuser <"+self.getName()+""">'s permissions appears to be corrupt.
+
+Please file a bug report explaining how you got here.\n"""+ str(e))
     self.__permissions = Permissions(self.getUser(),initialPermissions,writePath=self.getPermissionsDotJsonWritePath())
 
   def getPermissions(self):
@@ -135,7 +140,7 @@ To repair your subuser installation.\n""")
 
   def editPermissionsCLI(self):
     while True:
-      subuserlib.subprocessExtras.runEditor(self.getPermissions().getWritePath())
+      self.getUser().getEndUser().runEditor(self.getPermissions().getWritePath())
       try:
         initialPermissions = subuserlib.permissions.load(permissionsFilePath=self.getPermissionsDotJsonWritePath())
         break
@@ -171,6 +176,9 @@ To repair your subuser installation.\n""")
     """
     self.__imageId = imageId
 
+  def isImageInstalled(self):
+    return self.getUser().getDockerDaemon().getImageProperties(self.getImageId()) is not None
+
   def getServiceSubuserNames(self):
     """
     Get this subuser's service subusers.
@@ -284,7 +292,7 @@ To repair your subuser installation.\n""")
     """
     redirect = script
     executablePath=os.path.join(self.getUser().getConfig()["bin-dir"], name)
-    with open(executablePath, 'w') as file_f:
+    with self.getUser().getEndUser().get_file(executablePath, 'w') as file_f:
       file_f.write(redirect)
       st = os.stat(executablePath)
       os.chmod(executablePath, stat.S_IMODE(st.st_mode) | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
